Title: [290573] trunk
Revision
290573
Author
grao...@webkit.org
Date
2022-02-27 15:52:38 -0800 (Sun, 27 Feb 2022)

Log Message

[web-animations] web-animations/timing-model/animations/setting-the-timeline-of-an-animation.html is a unique failure
https://bugs.webkit.org/show_bug.cgi?id=237257

Reviewed by Dean Jackson.

LayoutTests/imported/w3c:

Mark WPT progressions.

* web-platform-tests/web-animations/timing-model/animations/setting-the-timeline-of-an-animation-expected.txt:

Source/WebCore:

The spec has changed since we initially implemented Animation.playState and we missed one condition for
an animation's play state to be "idle".

* animation/WebAnimation.cpp:
(WebCore::WebAnimation::playState const):

Modified Paths

Diff

Modified: trunk/LayoutTests/imported/w3c/ChangeLog (290572 => 290573)


--- trunk/LayoutTests/imported/w3c/ChangeLog	2022-02-27 22:19:14 UTC (rev 290572)
+++ trunk/LayoutTests/imported/w3c/ChangeLog	2022-02-27 23:52:38 UTC (rev 290573)
@@ -1,5 +1,16 @@
 2022-02-27  Antoine Quint  <grao...@webkit.org>
 
+        [web-animations] web-animations/timing-model/animations/setting-the-timeline-of-an-animation.html is a unique failure
+        https://bugs.webkit.org/show_bug.cgi?id=237257
+
+        Reviewed by Dean Jackson.
+
+        Mark WPT progressions.
+
+        * web-platform-tests/web-animations/timing-model/animations/setting-the-timeline-of-an-animation-expected.txt:
+
+2022-02-27  Antoine Quint  <grao...@webkit.org>
+
         [svg] flood-opacity should be clamped to the [0,1] range
         https://bugs.webkit.org/show_bug.cgi?id=237253
 

Modified: trunk/LayoutTests/imported/w3c/web-platform-tests/web-animations/timing-model/animations/setting-the-timeline-of-an-animation-expected.txt (290572 => 290573)


--- trunk/LayoutTests/imported/w3c/web-platform-tests/web-animations/timing-model/animations/setting-the-timeline-of-an-animation-expected.txt	2022-02-27 22:19:14 UTC (rev 290572)
+++ trunk/LayoutTests/imported/w3c/web-platform-tests/web-animations/timing-model/animations/setting-the-timeline-of-an-animation-expected.txt	2022-02-27 23:52:38 UTC (rev 290573)
@@ -2,13 +2,13 @@
 PASS After setting timeline on paused animation it is still paused
 PASS After setting timeline on animation paused outside active interval it is still paused
 PASS After setting timeline on an idle animation without a start time it is still idle
-FAIL After transitioning from a null timeline on an animation with a start time it is still running assert_equals: expected "running" but got "idle"
-FAIL After transitioning from a null timeline on an animation with a sufficiently ancient start time it is finished assert_equals: expected "running" but got "idle"
+PASS After transitioning from a null timeline on an animation with a start time it is still running
+PASS After transitioning from a null timeline on an animation with a sufficiently ancient start time it is finished
 PASS After setting timeline on a play-pending animation it begins playing after pending
 PASS After setting timeline on a pause-pending animation it becomes paused after pending
 PASS After clearing timeline on paused animation it is still paused
-FAIL After clearing timeline on finished animation it is running assert_equals: expected "running" but got "idle"
-FAIL After clearing timeline on running animation it is still running assert_equals: expected "running" but got "idle"
+PASS After clearing timeline on finished animation it is running
+PASS After clearing timeline on running animation it is still running
 PASS After clearing timeline on idle animation it is still idle
 PASS After clearing timeline on play-pending animation it is still pending
 PASS After clearing and re-setting timeline on play-pending animation it begins to play

Modified: trunk/Source/WebCore/ChangeLog (290572 => 290573)


--- trunk/Source/WebCore/ChangeLog	2022-02-27 22:19:14 UTC (rev 290572)
+++ trunk/Source/WebCore/ChangeLog	2022-02-27 23:52:38 UTC (rev 290573)
@@ -1,3 +1,16 @@
+2022-02-27  Antoine Quint  <grao...@webkit.org>
+
+        [web-animations] web-animations/timing-model/animations/setting-the-timeline-of-an-animation.html is a unique failure
+        https://bugs.webkit.org/show_bug.cgi?id=237257
+
+        Reviewed by Dean Jackson.
+
+        The spec has changed since we initially implemented Animation.playState and we missed one condition for
+        an animation's play state to be "idle".
+
+        * animation/WebAnimation.cpp:
+        (WebCore::WebAnimation::playState const):
+
 2022-02-27  Matt Woodrow  <mattwood...@apple.com>
 
         Handle reverse flow direction when converting iterator coords for a subgrid

Modified: trunk/Source/WebCore/animation/WebAnimation.cpp (290572 => 290573)


--- trunk/Source/WebCore/animation/WebAnimation.cpp	2022-02-27 22:19:14 UTC (rev 290572)
+++ trunk/Source/WebCore/animation/WebAnimation.cpp	2022-02-27 23:52:38 UTC (rev 290573)
@@ -644,11 +644,11 @@
     // The play state of animation, animation, at a given moment is the state corresponding to the
     // first matching condition from the following:
 
     // The current time of animation is unresolved, and animation does not have either a pending
     // play task or a pending pause task,
     // → idle
     auto animationCurrentTime = currentTime();
-    if (!animationCurrentTime && !pending())
+    if (!animationCurrentTime && !m_startTime && !pending())
         return PlayState::Idle;
 
     // Animation has a pending pause task, or both the start time of animation is unresolved and it does not
@@ -644,11 +644,11 @@
     // first matching condition from the following:
 
-    // The current time of animation is unresolved, and animation does not have either a pending
-    // play task or a pending pause task,
+    // The current time of animation is unresolved, and the start time of animation is unresolved, and
+    // animation does not have either a pending play task or a pending pause task,
     // → idle
     auto animationCurrentTime = currentTime();
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to